# -*- coding: utf-8 -*-
"""
@author: python273
@contact: https://vk.com/python273
@license Apache License, Version 2.0, see LICENSE file

Copyright (C) 2018
"""

from enum import Enum, IntEnum


class VkUserPermissions(IntEnum):
    """
    Перечисление прав пользователя.
    Список прав получается побитовым сложением (x & y) каждого права.
    Подробнее в документации VK API: https://vk.com/dev/permissions
    """
    NOTIFY = 1
    """
    Пользователь разрешил отправлять ему уведомления (для flash/iframe-приложений).
    Это право бесполезно для этой библиотеки.
    """
    FRIEND = 2
    """Доступ к друзьям."""
    PHOTOS = 2**2
    """Доступ к фотографиям."""
    AUDIO = 2**3
    """
    Доступ к аудиозаписям.
    При отсутствии доступа к закрытому API аудиозаписей это право позволяет только загрузку аудио.
    """
    VIDEO = 2**4
    """Доступ к видеозаписям."""
    STORIES = 2**6
    """Доступ к историям."""
    PAGES = 2**7
    """Доступ к wiki-страницам."""
    ADD_LINK = 2**8
    """Добавление ссылки на приложение в меню слева."""
    STATUS = 2**10
    """Доступ к статусу пользователя."""
    NOTES = 2**11
    """Доступ к заметкам пользователя."""
    MESSAGES = 2**12
    """Доступ к расширенным методам работы с сообщениями."""
    WALL = 2**13
    """Доступ к обычным и расширенным методам работы со стеной."""
    ADS = 2**15
    """Доступ к расширенным методам работы с рекламным API."""
    OFFLINE = 2**16
    """
    Доступ к API в любое время.
    Рекомендуется при работе с этой библиотекой.
    """
    DOCS = 2**17
    """Доступ к документам."""
    GROUPS = 2**18
    """Доступ к группам пользователя."""
    NOTIFICATIONS = 2**19
    """Доступ к оповещениям об ответах пользователю."""
    STATS = 2**20
    """Доступ к статистике групп и приложений пользователя, администратором которых он является."""
    EMAIL = 2**22
    """Доступ к email пользователя."""
    MARKET = 2**27
    """Доступ к товарам."""
